@@ -1445,7 +1445,8 @@ class IdaDataFrame(object):
     def info(self, buf=None):
         """Some information about current IdaDataFrame. NOTIMPLEMENTED"""
         # There is a lot more
-        from pandas.core.format import _put_lines
+        #from pandas.core.format import _put_lines
+        raise IdaDataFrameError("NOT IMPLEMENTED")
 
         if buf is None:  # pragma: no cover
             buf = sys.stdout
@@ -1568,6 +1569,40 @@ class IdaDataFrame(object):
         #return corr(idadf=self, features=features, ignore_indexer=ignore_indexer)
         return corr(idadf=self)
 
+    @timed
+
+    def train_test_split(self, train_table, test_table, id, fraction, seed):
+        """
+        Split the table into train and test sets
+
+        Parameters
+        ----------
+        train_table : str
+            the output table that will contain the given fraction of the input records
+
+        test_table :str
+            the output table that will contain the rest (1-<fraction>) of the input records
+
+        id : str
+            the input table column identifying a unique instance id
+
+        fraction: float
+             the fraction of the data to split
+
+        seed: float
+            the seed of the random function
+
+        Returns
+        -------
+        number of records in train table: float
+
+
+
+        """
+        from ibmdbpy4nps.statistics import train_test_split
+
+        return train_test_split(idadf=self, train_table=train_table, test_table=test_table, id=id, fraction=fraction, seed=seed)
+
     # TODO: to implement
     @timed
     @idadf_state
@@ -2110,6 +2145,12 @@ class IdaDataFrame(object):
             columns = self._idadb._con.cursor().columns(table=tablename, schema=schema)
             columnlist = [column[3] for column in columns]
             return Index(columnlist)
+        elif self._idadb._con_type == 'nzpy':
+            cursor = self._idadb._con.cursor()
+            cursor.execute("SELECT * FROM %s LIMIT 1"%tablename)
+            columnlist = [str(column[0],"utf-8") for column in cursor.description]
+            cursor.close()
+            return Index(columnlist)
         elif self._idadb._con_type == 'jdbc':
             cursor = self._idadb._con.cursor()
             cursor.execute("SELECT * FROM %s"%tablename)
